tests package — django_dicom 0.1.0 documentation

# tests package

## Subpackages

- tests.data_import package
  - Submodules
  - tests.data_import.test_import_image module
  - tests.data_import.test_local_import module
  - Module contents
- tests.models package
  - Submodules
  - tests.models.test_fields module
  - tests.models.test_image module
  - tests.models.test_patient module
  - tests.models.test_series module
  - tests.models.test_study module
  - Module contents
- tests.reader package
  - Submodules
  - tests.reader.test_header_information module
  - tests.reader.test_parser module
  - Module contents

## Submodules

## tests.fixtures module

## tests.test_settings module

## tests.test_views module

## Module contents